@@ -53,7 +53,8 @@ class GSPeerConnectionBroadcaster:
             return player.audio, player.video
         else:
             options = {"framerate": str(self.gsdbs.credentials["framerate"]),
-                       "video_size": f"{str(self.gsdbs.credentials['hres'])}x{str(self.gsdbs.credentials['vres'])}", }
+                       "video_size": f"{str(self.gsdbs.credentials['hres'])}x{str(self.gsdbs.credentials['vres'])}",
+                       "b:v": f" {self.gsdbs.credentials['hres'] * self.gsdbs.credentials['vres'] * self.gsdbs.credentials['framerate'] * 0.150}"}
             if relay is None:
                 if platform.system() == "Darwin":
                     webcam = MediaPlayer(
